@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.23";
+  $VERSION= "3.24";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -99,6 +99,7 @@ package Apache2::AMFWURFLFilter;
   my $cookiecachesystem="false";
   my $WURFLVersion="unknown";
   my $WURFLPatchVersion="unknown";
+  my $personalwurflurl='unknown';
   my $cachedirectorystore="/tmp";
   my $capabilitylist="none";
   my $restmode='false';
@@ -167,9 +168,15 @@ sub loadConfigFile {
 	      	$CommonLib->printLog("Start read configuration from httpd.conf");
 	
 	      	 if ($ENV{WurflNetDownload}) {
-				$wurflnetdownload=$ENV{WurflNetDownload};
-				$CommonLib->printLog("WurflNetDownload is: $wurflnetdownload");
-		}	
+				if ($ENV{WurflNetDownload} eq 'true' || $ENV{WurflNetDownload} eq 'false') {
+					$wurflnetdownload=$ENV{WurflNetDownload};
+					$CommonLib->printLog("WurflNetDownload is: $wurflnetdownload");
+				} else {
+					$CommonLib->printLog("Error WurflNetDownload parmeter must set to true or false");					
+					ModPerl::Util::exit();
+				}
+		}
+		 
 	      	 if ($ENV{DownloadWurflURL}) {
 				$downloadwurflurl=$ENV{DownloadWurflURL};
 				$CommonLib->printLog("DownloadWurflURL is: $downloadwurflurl");
@@ -201,9 +208,14 @@ sub loadConfigFile {
 				$CommonLib->printLog("LoadWebPatch is: $loadwebpatch");
 			 }	
 	      	 if ($ENV{PatchWurflNetDownload}) {
-				$patchwurflnetdownload=$ENV{PatchWurflNetDownload};
-				$CommonLib->printLog("PatchWurflNetDownload is: $patchwurflnetdownload");
-			 }	
+				if ($ENV{PatchWurflNetDownload} eq 'true' || $ENV{PatchWurflNetDownload} eq 'false') {
+					$patchwurflnetdownload=$ENV{PatchWurflNetDownload};
+					$CommonLib->printLog("PatchWurflNetDownload is: $patchwurflnetdownload");
+				} else {
+					$CommonLib->printLog("Error PatchWurflNetDownload parmeter must set to true or false");					
+					ModPerl::Util::exit();
+				}
+		}	
 	      	 if ($ENV{PatchWurflUrl}) {
 				$patchwurflurl=$ENV{PatchWurflUrl};
 				$CommonLib->printLog("PatchWurflUrl is: $patchwurflurl");
@@ -215,7 +227,14 @@ sub loadConfigFile {
 			 } else {
 				$CommonLib->printLog("AMFProductionMode (the CookieCacheSystem is deprecated) is not setted the default value is $cookiecachesystem");			   
 			 }		
-
+		if ($ENV{PersonalWurflFileName}) {
+			$personalwurflurl=$ENV{AMFMobileHome}."/".$ENV{PersonalWurflFileName};
+			$CommonLib->printLog("PersonalWurflFileName is: $ENV{PersonalWurflFileName}");
+		}
+		if ($ENV{RestMode}) {
+			$restmode=$ENV{RestMode};
+			$CommonLib->printLog("RestMode is: $restmode");
+		}
 	    $CommonLib->printLog("Finish loading  parameter");
 		$CommonLib->printLog("---------------------------------------------------------------------------"); 
 	    if ($wurflnetdownload eq "true") {
@@ -339,13 +358,14 @@ sub loadConfigFile {
 				}
 			}
 		}
-		my $arrLen = scalar %Array_fb;
-		($arrLen,$dummy)= split(/\//, $arrLen);
-		if ($arrLen == 0) {
+		close IN;
+	my $arrLen = scalar %Array_fb;
+	($arrLen,$dummy)= split(/\//, $arrLen);
+	if ($arrLen == 0) {
 		     $CommonLib->printLog("Error the file probably is not a wurfl file, control the url or path");
 		     $CommonLib->printLog("Control also if the file is compress file, and DownloadZipFile parameter is seted false");
 		     ModPerl::Util::exit();
-		}
+	}
         $CommonLib->printLog("WURFL version: $WURFLVersion");
 	if ($WURFLVersion ne 'unknown'){
 		$CommonLib->printLog("Patch File version: $WURFLPatchVersion");		
@@ -368,11 +388,36 @@ sub loadConfigFile {
         }
         $CommonLib->printLog("This version of WURFL has $arrLen UserAgent");
         $CommonLib->printLog("End loading  WURFL.xml");
-	if ($ENV{RestMode}) {
-		$restmode=$ENV{RestMode};
-		$CommonLib->printLog("RestMode is: $restmode");
+	if ($personalwurflurl ne 'unknown') {
+		$CommonLib->printLog("---------------------------------------------------------------------------"); 
+		if (-e "$personalwurflurl") {
+					$CommonLib->printLog("Start loading  $ENV{PersonalWurflFileName}");
+					if (open (IN,"$personalwurflurl")) {
+						my $filesize= -s $personalwurflurl;
+						my $string_file;
+						read (IN,$string_file,$filesize);
+						close IN;
+						$string_file =~ s/\n//g;
+						$string_file =~ s/>/>\n/g;
+						my @arrayFile=split(/\n/, $string_file);
+						foreach my $line (@arrayFile) {
+						#print "$line\n";
+							$r_id=parseWURFLFile($line,$r_id);
+						}
+					} else {
+					    $CommonLib->printLog("Error open file:$personalwurflurl");
+					    ModPerl::Util::exit();
+					}
+					$CommonLib->printLog("END loading  $ENV{PersonalWurflFileName}");
+					close IN;
+		
+		} else {
+			  $CommonLib->printLog("File $personalwurflurl not found");
+			  ModPerl::Util::exit();
+		}
 	}
 
+
 }
 sub callparseWURFLFile {
 	 my ($output) = @_;
@@ -437,7 +482,7 @@ sub parseWURFLFile {
 								$Array_id{$dummy}=$id;
 							    }
 				                $contaUA=$contaUA-1;
-						 }
+					  }
 				 }
 				 
 		 }
